pub struct DirectorySiteSettings {
pub interstitial_placement_accepted: Option<bool>,
pub nielsen_ocr_opt_out: Option<bool>,
pub active_view_opt_out: Option<bool>,
pub video_active_view_opt_out: Option<bool>,
pub dfp_settings: Option<DfpSettings>,
pub verification_tag_opt_out: Option<bool>,
pub instream_video_placement_accepted: Option<bool>,
}Expand description
Directory Site Settings
This type is not used in any activity, and only used as part of another schema.
Fields
interstitial_placement_accepted: Option<bool>Whether this site accepts interstitial ads.
nielsen_ocr_opt_out: Option<bool>Whether this directory site has disabled Nielsen OCR reach ratings.
active_view_opt_out: Option<bool>Whether this directory site has disabled active view creatives.
video_active_view_opt_out: Option<bool>Whether this directory site has disabled active view for in-stream video creatives.
dfp_settings: Option<DfpSettings>Directory site DFP settings.
verification_tag_opt_out: Option<bool>Whether this directory site has disabled generation of Verification ins tags.
instream_video_placement_accepted: Option<bool>Whether this site accepts in-stream video ads.