pub struct DirectorySitesListResponse {
pub next_page_token: Option<String>,
pub kind: Option<String>,
pub directory_sites: Option<Vec<DirectorySite>>,
}Expand description
Directory Site List Response
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list directory sites (response)
Fields
next_page_token: Option<String>Pagination token to be used for the next list operation.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “dfareporting#directorySitesListResponse”.
directory_sites: Option<Vec<DirectorySite>>Directory site collection.