Struct google_dfareporting2d5::FloodlightReportCompatibleFields
[−]
[src]
pub struct FloodlightReportCompatibleFields {
pub metrics: Option<Vec<Metric>>,
pub kind: Option<String>,
pub dimension_filters: Option<Vec<Dimension>>,
pub dimensions: Option<Vec<Dimension>>,
}Represents fields that are compatible to be selected for a report of type "FlOODLIGHT".
This type is not used in any activity, and only used as part of another schema.
Fields
metrics: Option<Vec<Metric>>
Metrics which are compatible to be selected in the "metricNames" section of the report.
kind: Option<String>
The kind of resource this is, in this case dfareporting#floodlightReportCompatibleFields.
dimension_filters: Option<Vec<Dimension>>
Dimensions which are compatible to be selected in the "dimensionFilters" section of the report.
dimensions: Option<Vec<Dimension>>
Dimensions which are compatible to be selected in the "dimensions" section of the report.