pub struct GeoTargeting {
pub regions: Option<Vec<Region>>,
pub countries: Option<Vec<Country>>,
pub metros: Option<Vec<Metro>>,
pub cities: Option<Vec<City>>,
pub exclude_countries: Option<bool>,
pub postal_codes: Option<Vec<PostalCode>>,
}Expand description
Geographical Targeting.
This type is not used in any activity, and only used as part of another schema.
Fields
regions: Option<Vec<Region>>Regions to be targeted. For each region only dartId is required. The other fields are populated automatically when the ad is inserted or updated. If targeting a region, do not target or exclude the country of the region.
countries: Option<Vec<Country>>Countries to be targeted or excluded from targeting, depending on the setting of the excludeCountries field. For each country only dartId is required. The other fields are populated automatically when the ad is inserted or updated. If targeting or excluding a country, do not target regions, cities, metros, or postal codes in the same country.
metros: Option<Vec<Metro>>Metros to be targeted. For each metro only dmaId is required. The other fields are populated automatically when the ad is inserted or updated. If targeting a metro, do not target or exclude the country of the metro.
cities: Option<Vec<City>>Cities to be targeted. For each city only dartId is required. The other fields are populated automatically when the ad is inserted or updated. If targeting a city, do not target or exclude the country of the city, and do not target the metro or region of the city.
exclude_countries: Option<bool>Whether or not to exclude the countries in the countries field from targeting. If false, the countries field refers to countries which will be targeted by the ad.
postal_codes: Option<Vec<PostalCode>>Postal codes to be targeted. For each postal code only id is required. The other fields are populated automatically when the ad is inserted or updated. If targeting a postal code, do not target or exclude the country of the postal code.