pub struct UserRolePermissionGroupsListResponse {
pub user_role_permission_groups: Option<Vec<UserRolePermissionGroup>>,
pub kind: Option<String>,
}Expand description
User Role Permission Group List Response
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list user role permission groups (response)
Fields
user_role_permission_groups: Option<Vec<UserRolePermissionGroup>>User role permission group collection.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “dfareporting#userRolePermissionGroupsListResponse”.